pub struct CheckResult {
pub is_safe: bool,
pub ip: String,
pub ip_type: IpType,
}Fields
is_safe: boolThe user is using an exit that may be Obscura traffic.
Either way the user is not coming from an unknown IP range.
ip: Stringip_type: IpTypeTrait Implementations
Sourceimpl Clone for CheckResult
impl Clone for CheckResult
Sourcefn clone(&self) -> CheckResult
fn clone(&self) -> CheckResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CheckResult
impl Debug for CheckResult
Sourceimpl<'de> Deserialize<'de> for CheckResult
impl<'de> Deserialize<'de> for CheckResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CheckResult
impl PartialEq for CheckResult
Sourceimpl Serialize for CheckResult
impl Serialize for CheckResult
impl StructuralPartialEq for CheckResult